@@ -3,7 +3,7 @@ from typing import Generator
 import grpc 
 
 from protmo.provide import provide
-from protmo.server.user import User
+from protmo.server.user import User, USER_KEY
 from protmo.db import DB_KEY, Db
 from protmo.pm import Message
 from protmo.settings_loader import settings
@@ -14,7 +14,7 @@ from grpc._server import _Context
 from typing import Any
 from protmo.pm import _rpc_methods, name_to_grpc_message_or_method # TODO: these two belong somewhere else...
 
-USER_KEY=2
+
 
 class GenericServicer:
     '''
@@ -126,8 +126,11 @@ class GenericServicer:
                 mongo_settings = settings.get('mongodb', {})
                 db = Db(
                     mongo_settings.get('host', 'localhost'),
-                    mongo_settings.get('port', 27017), 
-                    context.realm)
+                    mongo_settings.get('port', 27017),
+                    context.realm
+                    username=mongo_settings.get('username'),
+                    password=mongo_settings.get('password')
+                    )
                 
                 # First if: Uniary call or Client-Side-Streaming
                 if isinstance(request, grpc._server._RequestIterator): # streaming call
